@@ -48,7 +48,25 @@ class PlanEntry:
     diagnostics: list[str] = field(default_factory=list)
 
     def to_payload(self) -> dict[str, t.Any]:
-        """Convert the plan entry into a serialisable payload."""
+        """Convert the plan entry into a serialisable payload.
+
+        Examples
+        --------
+        >>> entry = PlanEntry(
+        ...     name="myrepo",
+        ...     path="/home/user/repos/myrepo",
+        ...     workspace_root="/home/user/repos",
+        ...     action=PlanAction.CLONE,
+        ...     url="git+https://github.com/user/myrepo.git",
+        ... )
+        >>> payload = entry.to_payload()
+        >>> payload["name"]
+        'myrepo'
+        >>> payload["action"]
+        'clone'
+        >>> payload["format_version"]
+        '1'
+        """
         payload: dict[str, t.Any] = {
             "format_version": "1",
             "type": "operation",
@@ -94,11 +112,28 @@ class PlanSummary:
     duration_ms: int | None = None
 
     def total(self) -> int:
-        """Return the total number of repositories accounted for."""
+        """Return the total number of repositories accounted for.
+
+        Examples
+        --------
+        >>> summary = PlanSummary(clone=2, update=3, unchanged=1)
+        >>> summary.total()
+        6
+        """
         return self.clone + self.update + self.unchanged + self.blocked + self.errors
 
     def to_payload(self) -> dict[str, t.Any]:
-        """Convert the summary to a serialisable payload."""
+        """Convert the summary to a serialisable payload.
+
+        Examples
+        --------
+        >>> summary = PlanSummary(clone=1, update=2)
+        >>> payload = summary.to_payload()
+        >>> payload["type"]
+        'summary'
+        >>> payload["total"]
+        3
+        """
         payload: dict[str, t.Any] = {
             "format_version": "1",
             "type": "summary",
@@ -132,29 +167,6 @@ class PlanResult:
     entries: list[PlanEntry]
     summary: PlanSummary
 
-    def to_workspace_mapping(self) -> dict[str, list[PlanEntry]]:
-        """Group plan entries by workspace root."""
-        grouped: dict[str, list[PlanEntry]] = {}
-        for entry in self.entries:
-            grouped.setdefault(entry.workspace_root, []).append(entry)
-        return grouped
-
-    def to_json_object(self) -> dict[str, t.Any]:
-        """Return the JSON structure for ``--json`` output."""
-        workspaces: list[dict[str, t.Any]] = []
-        for workspace_root, entries in self.to_workspace_mapping().items():
-            workspaces.append(
-                {
-                    "path": workspace_root,
-                    "operations": [entry.to_payload() for entry in entries],
-                },
-            )
-        return {
-            "format_version": "1",
-            "workspaces": workspaces,
-            "summary": self.summary.to_payload(),
-        }
-
 
 class OutputFormatter:
     """Manages output formatting for different modes (human, JSON, NDJSON)."""
@@ -166,6 +178,12 @@ class OutputFormatter:
         ----------
         mode : OutputMode
             The output mode to use (human, json, ndjson)
+
+        Examples
+        --------
+        >>> formatter = OutputFormatter(OutputMode.JSON)
+        >>> formatter.mode
+        <OutputMode.JSON: 'json'>
         """
         self.mode = mode
         self._json_buffer: list[dict[str, t.Any]] = []
@@ -207,7 +225,7 @@ class OutputFormatter:
 
     def finalize(self) -> None:
         """Finalize output (flush JSON buffer if needed)."""
-        if self.mode == OutputMode.JSON and self._json_buffer:
+        if self.mode == OutputMode.JSON:
             sys.stdout.write(json.dumps(self._json_buffer, indent=2) + "\n")
             sys.stdout.flush()
             self._json_buffer.clear()
@@ -227,6 +245,15 @@ def get_output_mode(json_flag: bool, ndjson_flag: bool) -> OutputMode:
     -------
     OutputMode
         The determined output mode (NDJSON takes precedence over JSON)
+
+    Examples
+    --------
+    >>> get_output_mode(json_flag=False, ndjson_flag=False)
+    <OutputMode.HUMAN: 'human'>
+    >>> get_output_mode(json_flag=True, ndjson_flag=False)
+    <OutputMode.JSON: 'json'>
+    >>> get_output_mode(json_flag=True, ndjson_flag=True)
+    <OutputMode.NDJSON: 'ndjson'>
     """
     if ndjson_flag:
         return OutputMode.NDJSON
