@@ -297,8 +297,8 @@ def check_repo_status(repo: ConfigDict, detailed: bool = False) -> dict[str, t.A
                 if branch_result is not None:
                     status["branch"] = branch_result.stdout.strip()
 
-                ahead = 0
-                behind = 0
+                ahead: int | None = None
+                behind: int | None = None
                 upstream_available = _run_git_command(
                     repo_path,
                     "rev-parse",
@@ -443,9 +443,9 @@ def status_repos(
 
         if status["exists"]:
             summary["exists"] += 1
-            if status["clean"]:
+            if status["clean"] is True:
                 summary["clean"] += 1
-            else:
+            elif status["clean"] is False:
                 summary["dirty"] += 1
         else:
             summary["missing"] += 1
